==> Elive-StandardV2-0.00_8.tar.gz: Elive-StandardV2-0.00_8/lib/Elive/StandardV2/SessionAttendance.pm <==
package Elive::StandardV2::SessionAttendance;
use warnings; use strict;

use Mouse;
use Carp;

extends 'Elive::StandardV2';

use Elive::StandardV2::SessionAttendance::Attendees;

=head1 NAME

Elive::StandardV2::SessionAttendance - Elluminate Session Attendance Report

=head1 DESCRIPTION

This is the main entity class for attendees.

=cut

__PACKAGE__->entity_name('SessionAttendance');
__PACKAGE__->params(sessionId => 'Int',
		    startTime => 'HiResDate',
		    endTime => 'HiResDate',
    );

has 'roomName' => (is => 'rw', isa => 'Str', required => 1,
		   documentation => 'Name of the room'
    );

has 'roomOpened' => (is => 'rw', isa => 'HiResDate', required => 1,
		       documentation => 'date and time that the session was launched');

has 'roomClosed' => (is => 'rw', isa => 'HiResDate', required => 1,
		       documentation => 'date and time that room shut down');

has 'attendees' => (is => 'rw', isa => 'Elive::StandardV2::SessionAttendance::Attendees',
		    coerce => 1, documentation => 'Session attendees',);

# give soap a helping hand
__PACKAGE__->_alias(attendeeResponseCollection => 'attendees');

=head1 METHODS

=cut

=head2 list

    my $session_id = '123456789012';
    my $yesterday = DateTime->today->subtract(days => 1);

    my $attendance = Elive::StandardV2::SessionAttendance->list(
                                    sessionId => $session_id,
                                    startTime => $yesterday->epoch.'000');

Gets a session attendance report. It returns a reference to an array of Elive::StandardV2::SessionAttendance objects.

=cut

1;

==> Elive-StandardV2-0.01_0.tar.gz: Elive-StandardV2-0.01_0/lib/Elive/StandardV2/SessionAttendance.pm <==
package Elive::StandardV2::SessionAttendance;
use warnings; use strict;

use Mouse;
use Carp;

extends 'Elive::StandardV2';

use Elive::StandardV2::SessionAttendance::Attendees;

=head1 NAME

Elive::StandardV2::SessionAttendance - Elluminate Session Attendance Report

=head1 DESCRIPTION

This is the main entity class for session attendance reports.

=cut

__PACKAGE__->entity_name('SessionAttendance');
__PACKAGE__->params(sessionId => 'Int',
		    startTime => 'HiResDate',
		    endTime => 'HiResDate',
    );

=head2 roomName (Str)

The name of the room. This is derived from the name of the session as it was defined at the time the scheduled session was launched.

=cut

has 'roomName' => (is => 'rw', isa => 'Str', required => 1,
		   documentation => 'Name of the room'
    );

=head2 roomOpened (HiResDate)

The date and time that the room opened (also known as the date and time session was launched) in milliseconds.

=cut

has 'roomOpened' => (is => 'rw', isa => 'HiResDate', required => 1,
		       documentation => 'date and time that the session was launched');

=head2 roomClosed (HiResDate)

The date and time that the room shut down.

=cut

has 'roomClosed' => (is => 'rw', isa => 'HiResDate', required => 1,
		       documentation => 'date and time that room shut down');

=head2 attendees (Arr)

This is a collection of L<Elive::StandardV2::SessionAttendance::Attendee> objects. This collection represents all the attendees who were present in this session between the roomOpen and roomClosed time.

Since guests can attend sessions, not all the attendees may be users in your system.

=cut

has 'attendees' => (is => 'rw', isa => 'Elive::StandardV2::SessionAttendance::Attendees',
		    coerce => 1, documentation => 'Session attendees',);

# give soap a helping hand
__PACKAGE__->_alias(attendeeResponseCollection => 'attendees');

=head1 METHODS

=cut

=head2 list

    my $session_id = '123456789012';
    my $yesterday = DateTime->today->subtract(days => 1);

    my $attendance = Elive::StandardV2::SessionAttendance->list(
                                    sessionId => $session_id,
                                    startTime => $yesterday->epoch.'000');

Gets a session attendance report. It returns a reference to an array of Elive::StandardV2::SessionAttendance objects.

=cut

1;
